package HT.fx;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.PrintStream;
import java.time.LocalDate;
import java.time.format.DateTimeFormatter;
import java.util.*;

import fi.jyu.mit.ohj2.Mjonot;

/**
 * @author joonatan
 * @version 7.3.2024
 *
 */
public class Ottelut implements Iterable<Ottelu> {

    private final Collection<Ottelu> alkiot = new ArrayList<Ottelu>();
    

    /**
     * Tyhjä konstruktori
     */
    public Ottelut() {
        
    }
    
    /**
     * @param ott ottelu
     */
    public void lisaa(Ottelu ott) {
        alkiot.add(ott);
    }
    
    /**
     * Luo listan otteluista jotta saadaan palautettua yksi ottelu. 
     * Ominaisuus saattaa jäädä turhaksi myöhemmin
     * @param i monesko 
     * @return ottelu
     */
    public Ottelu haeOttelu(int i) {
        List<Ottelu> loydetyt = new ArrayList<Ottelu>();
        for(Ottelu ott : alkiot)
            loydetyt.add(ott);
        return loydetyt.get(i);
    }
    
    /**
     * Luo listan otteluista joka palautetaan
     * 
     * @return Lista kaikista otteluista
     */
    public List<Ottelu> haeOttelut() {
        List<Ottelu> loydetyt = new ArrayList<Ottelu>();
        for(Ottelu ott : alkiot)
            loydetyt.add(ott);
        return loydetyt;
    }
    /**
     * Palauttaa otteluiden lukumäärän
     * @return otteluiden lukumäärä
     */
    public int getLkm() {
        return alkiot.size();
    }
    
    
    @Override
    public Iterator<Ottelu> iterator() {
        return alkiot.iterator();
    }
    
    /**
     * Haetaan pelaajien ottelut
     * @param tunnusnro2 pelaajan tunnusnro
     * @return Tietorakenne jossa viitteet löydettyihin otteluihin
     */
    public List<Ottelu> annaOttelut(int tunnusnro2) {
        List<Ottelu> loydetyt = new ArrayList<Ottelu>();
        for(Ottelu ott : alkiot) {
            int i = 0;
            
            while(i<4){
                if (ott.getPelaajaNrot()[i] == tunnusnro2) loydetyt.add(ott);
                i++;
            }
        }
        return loydetyt;
    }

    /**
     * tallentaa pelaajien tiedot ottelutietoihin
     */
    public void talleta() {
        try (PrintStream fo = new PrintStream(new FileOutputStream("Ottelutiedot", false)))  {
            int i = 0;
            while ( i<PadelMainGUIController.getKarkelo().noudaOttelut().size()) {
                
                fo.print(PadelMainGUIController.getKarkelo().noudaOttelu(i).getTiedot()+ "\n");
                i++;
                
            }
            
        } catch(FileNotFoundException ex) {
            System.err.println("Tiedosto ei aukea: " + ex.getMessage());
        }
        
    }

    /**
     * lukee ottelutiedot tiedostosta
     * @param tiedosto luettava tiedosto
     */
    public void lueTiedostosta(String tiedosto) {
        try (Scanner fi = new Scanner(new FileInputStream(new File(tiedosto)))) { // Jotta UTF8/ISO-8859 toimii

            
            while ( fi.hasNext() ) {
                String s = fi.nextLine();
                if(s.length()>0) {
                    
                    
                    StringBuffer sb = new StringBuffer(s);
                    Ottelu ott = new Ottelu();
                   
                    ott.parse(sb);
                    lisaa(ott);
                    
                }
            }
        } catch (FileNotFoundException ex) {
            System.err.println("Tiedosto ei aukea! " + ex.getMessage());
            ex.printStackTrace();
            return;
        }
        

        
    }


    /**
     * Poistaa ottelun
     * @param ott poistettava ottelu
     */
    public void poistaOttelu(Ottelu ott) {
        alkiot.remove(ott);
        
    }
   
}