package HT.fx;

import java.io.OutputStream;
import java.io.PrintStream;
import java.time.LocalDate;
import java.time.Period;
import java.time.format.DateTimeFormatter;

import fi.jyu.mit.ohj2.Mjonot;

/**
 * @author joonatan, tuomas
 * @version 13.3.2024
 *
 */
public class Pelaaja {
    
    
    private int tunnusnro;
    private String nimi;
    private int rating;
    private boolean auto;
    private String sahkoposti; 
    private LocalDate syntymaaika;
    
    private static int seuraavaNro = 1;
    
    /**
     * @param nimi pelaajan nimi
     * @param syntymaaika pelaajan syntymaaika
     * @param sahkoposti pelaajan sähköposti
     * @param auto onko pelaajalla auto
     */
    public Pelaaja(String nimi, LocalDate syntymaaika, String sahkoposti, boolean auto) {
        this.nimi = nimi;
        this.syntymaaika = syntymaaika;
        this.rating = 1000;
        this.sahkoposti = sahkoposti; 
        this.auto = auto;
    }
    
    /**
     * @param tunnusnro tunnus
     * @param nimi pelaajan nimi
     * @param syntymaaika pelaajan syntymaaika
     * @param rating pelaajan rating
     * @param sahkoposti pelaajan sähköposti
     * @param auto onko pelaajalla auto
     */
    public Pelaaja(int tunnusnro, String nimi, LocalDate syntymaaika, int rating, String sahkoposti, boolean auto) {
        this.tunnusnro = tunnusnro;
        this.nimi = nimi;
        this.syntymaaika = syntymaaika;
        this.rating = rating;
        this.sahkoposti = sahkoposti; 
        this.auto = auto;
    }
    
    /**
     * Muodostaja tyhjän pelaajan luomiseen
     */
    public Pelaaja() {
        // TODO Auto-generated constructor stub
    }

    /**
     * Apumetodi, jolla saadaan täytettyä testiarvot jäsenelle.
     */
    public void luoTesti() {
        nimi = "Ankka Aku";
        syntymaaika = LocalDate.of(1951, 12, 5);  //5.12.1951";
        sahkoposti = "ankka.aku@luukku.fi";
        auto = true;   
    }
    
    /**
     * Tulostetaan henkilön tiedot
     * @param out tietovirta johon tulostetaan
     */
    public void tulosta(PrintStream out) {
        out.println(String.format("%03d", tunnusnro, 3) + "  " + nimi);
        out.println("     " + sahkoposti);
        out.println("     " + syntymaaika);
        if (auto) {out.println("     Pelaajalla on auto. ");}
    }
    
    /**
     * Tulostetaan henkilön tiedot
     * @param os tietovirta johon tulostetaan
     */
    public void tulosta(OutputStream os) {
        tulosta(new PrintStream(os));
    }
    
    
    /**
     * Erottelee pelaajatiedot tekstitiedostosta
     * @param sb luettava tiedosto
     */
    public void parse(StringBuffer sb) {
        seuraavaNro++;
        tunnusnro =  Integer.parseInt(Mjonot.erota(sb,'|',false));
        nimi = Mjonot.erota(sb,'|',false);
        String syntymapaiva = Mjonot.erota(sb,'|',false);
        DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy-M-d");
        LocalDate synt = LocalDate.parse(syntymapaiva, formatter);
        syntymaaika = synt;
        rating = Integer.parseInt(Mjonot.erota(sb,'|',false));
        sahkoposti = Mjonot.erota(sb,'|',false);
        String auto1 = Mjonot.erota(sb,'|',false);
        auto = false;
        if(Integer.parseInt(auto1)==1) {
            auto = true;
        }
    }
    
    /**
     * @return tiedot yhtenä rivinä erotettuna "|"
     */
    public String getTiedot() {
        int onkoauto = 0; 
        if(auto)onkoauto=1;
        return tunnusnro + "|"+ nimi+"|"+syntymaaika+"|"+rating+"|"+sahkoposti+"|"+onkoauto;
    }
    /**
     * @return palauttaa pelaajan nimen
     */
    public String getNimi() {
        return nimi;
    }
    
    /**
     * @return palauttaa pelaajan iän
     */
    public int getIka() {
        return Period.between(syntymaaika, LocalDate.now()).getYears();  
        
    }
    
    /**
     * @return palauttaa pelaajan syntymäajan
     */
    public LocalDate getSyntaika() {
        return syntymaaika;
        
    }

    
    /**
     * @return palauttaa pelaajan sähköpostin
     */
    public String getSahkoposti() {
        return sahkoposti;
    }
    
    /**
     * @return palauttaa tiedon onko pelaajalla auto, true = on auto
     */
    public boolean getAuto() {
        return auto;
    }

    
    /**
     * Antaa jäsenelle seuraavan rekisterinumeron.
     * @return jäsenen uusi tunnusNro
     * @example
     * <pre name="test">
     *   Pelaaja aku1 = new Pelaaja();
     *   aku1.getTunnusNro() === 0;
     *   aku1.rekisteroi();
     *   Pelaaja aku2 = new Pelaaja();
     *   aku2.rekisteroi();
     *   int n1 = aku1.getTunnusNro();
     *   int n2 = aku2.getTunnusNro();
     *   n1 === n2-1;
     * </pre>
     */
    public int rekisteroi() {
        tunnusnro = seuraavaNro;
        seuraavaNro++;
        return tunnusnro;
    }
    
    /**
     * Palauttaa jäsenen tunnusnumeron.
     * @return jäsenen tunnusnumero
     */
    public int getTunnusNro() {
        return tunnusnro;
    }
    
    /**
     * @return Palauttaa pelaajan ratingin
     */
    public int getRating() {
        return rating;
    }

    /**
     * @param rating Asettaa pelaajan ratingin
     */
    public void setRating(int rating) {
        this.rating = rating;
    }


    /**
     * @param text Asettaa pelaajan nimen
     */
    public void setNimi(String text) {
        nimi = text;
        
    }

    /**
     * @param value Asettaa pelaajan syntymäajan
     */
    public void setSyntaika(LocalDate value) {
        syntymaaika = value;
        
    }

    /**
     * @param text Asettaa pelaajan sähköpostin
     */
    public void setSahkoposti(String text) {
        sahkoposti = text;
        
    }

    /**
     * @param selected Määrittelee onko pelaajalla autoa
     */
    public void setOnkoauto(boolean selected) {
        auto = selected;
        
    }

    /**
     * @return palauttaa seuraavan pelaajan tunnusnumeron
     */
    public static int getSeuraavaNro() {
        // TODO Auto-generated method stub
        return seuraavaNro;
    }

    /**
     * asettaa pelaajan tunnusnumeroksi i:n
     * @param i pelaajan uusi tunnusnumero
     */
    public void setTunnusNro(int i) {
        tunnusnro=i;
        
    }

    /**
     * Asettaa seuraavan pelaajan tunnusnumeroksi numeron i
     * @param i uusi numero
     */
    public static void setSeuraavaNro(int i) {
        seuraavaNro = i;
        
    }
    
    
    /**
     * Testiohjelma jäsenelle.
     * @param args ei käytössä
     */
    public static void main(String args[]) {
        Pelaaja aku = new Pelaaja(), aku2 = new Pelaaja();
        aku.rekisteroi();
        aku2.rekisteroi();
        aku.tulosta(System.out);
        aku.luoTesti();
        aku.tulosta(System.out);

        aku2.luoTesti();
        aku2.tulosta(System.out);

        aku2.luoTesti();
        aku2.tulosta(System.out);
    }

}
